
function Y= Figure_1_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,QEsummary)
%This Code replicate Figures 1 from the paper
%%   Inputs:
%   Stats: Data base with income dynamics statistics 
%   Density: Data base with density
%   GDP_growth: Data base with GDP Growth 
%   name: Country Code
%   name_figure: Name of the Figure (See below)
%   Figure_name: Figure Number (Creates the directory)
%   code_plot: Name of the Figure (See below)
%   variable_1: Variables general to all figures
%   variables: Variables to plot (Specific for each figure)
%   age: Age-Group in the figures
%   gender: Gender in the figures
%   title_t: Title of the Figure (Actually saving without title)
%   Format: Struct with format
%   Dir: Struct with Directories
%   QEsummary: Data base with income dynamics statistics
%              Name of the Figure = [name_figure code_plot]
%% Outputs:
%   Figure 1 stored in the corresponding folder    


%Housekeeping
name_figure_store=name_figure;

%Graph specific
%Data Selector: Graph specific
logic_1=QEsummary.country==[name] & QEsummary.age==[age];
data_select=QEsummary(logic_1,[variable_1,variables]);

%Define labels for the Figure
y_label=[''];
x_label=['Years'];
y_label_2=[''];

%Create Figure
f1 = figure('Color',[1 1 1], 'Position',Format.L2_figsize,'defaultAxesColorOrder',[[0 0 0]; [0 0 0]]);
%Apply Margins
subaxis(1,1,1,'SpacingHoriz', Format.L2_spaceH, ...
        'SpacingVert',Format.L2_spaceV, 'PL',Format.L2_padding,'PR',Format.L2_padding,'mt',...
        Format.L2_marTop,'mb',Format.L2_marBot,'ML',Format.L2_marginL,'MR',Format.L2_marginR);

%Select Data
logic_b=data_select.gender==gender(1);
y1=table2array(data_select(logic_b,[variables(1)]));
x1=table2array(data_select(logic_b,["year"]));
y1_b=table2array(data_select(logic_b,[variables(2)]));

Y=[y1];
yyaxis left;
p2=plot(x1,Y);
 for linei = 1:size(Y,2)
        set(p2(linei),'LineStyle',Format.L2_styles{linei});
        set(p2(linei),'color',Format.L2_colors{linei});
        set(p2(linei),'linewidth',Format.L2_widths{linei});
        set(p2(linei),'marker',   Format.L2_marker{linei});
        set(p2(linei),'MarkerFaceColor', Format.L2_fillcolors{linei});
        set(p2(linei),'MarkerEdgeColor', Format.L2_Edgecolors{linei}) ;
        set(p2(linei),'MarkerSize', Format.L2_marker_size{linei}) ;
 end
set(gca,'FontSize',Format.L2_FontSize_axis_2,'XGrid','on','YGrid','on');
%Format y-axis
y=ylabel(y_label,'FontSize',Format.L2_FontSize_axis,'Interpreter','latex','FontWeight','bold');
set(y, 'Units', 'Normalized', 'Position', [-0.09, 0.5, 0]);


yyaxis right;
p3=plot(x1,y1_b);
 for linei = 2:2
         set(p3(linei-1),'LineStyle',Format.L2_styles{linei});
        set(p3(linei-1),'color',Format.L2_colors{linei});
        set(p3(linei-1),'linewidth',Format.L2_widths{linei});
        set(p3(linei-1),'marker',   Format.L2_marker{linei});
        set(p3(linei-1),'MarkerFaceColor', Format.L2_fillcolors{linei});
        set(p3(linei-1),'MarkerEdgeColor', Format.L2_Edgecolors{linei}) ;
        set(p3(linei-1),'MarkerSize', Format.L2_marker_size{linei}) ;
 end
%Format y-axis
ylabel(y_label_2,'FontSize',Format.L2_FontSize_axis,'Interpreter','latex','FontWeight','bold');

%Format x-axis
ax = gca;
ax.LineWidth=1;
logic_nan=~isnan(Y);
x_min=min(x1(logic_nan(:,1)))-1;
x_max=max(x1(logic_nan(:,1)))+1;
ax.XTick=[1975 1980 1985 1990 1995 2000 2005 2010 2015 2020];
xlim([x_min,x_max])

%Addign twist to Brazil and UK 
if string(name)==string(['BRA'])
xlim([2000,x_max])
elseif string(name)==string(['UK'])
xlim([1979,x_max])  
ax.XTick=[1975 1985 1995 2005 2015 ];
end

%Apply Legend to the first figure
if string(name)==string(['ARG'])
    %Legend
l_legend=["Gini, GRID (L)" "Gini, WID (R)" ];
legend(l_legend,'Location','best','FontSize',Format.P_FontSize_legend,'Box','on',Interpreter='latex');
end

name_figure=[ name_figure_store];

%Storing Files
Storing_figures;

cd(Dir.Main_directory)
close all
end
