
function Y= Figure_2_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,QEsummary,P9010,P9050,P5010,Countries)
%This Code replicate Figures 3 from the paper
%%   Inputs:
%   Stats: Data base with income dynamics statistics 
%   Density: Data base with density
%   GDP_growth: Data base with GDP Growth 
%   name: Country Code
%   name_figure: Name of the Figure (See below)
%   Figure_name: Figure Number (Creates the directory)
%   code_plot: Name of the Figure (See below)
%   variable_1: Variables general to all figures
%   variables: Variables to plot (Specific for each figure)
%   age: Age-Group in the figures
%   gender: Gender in the figures
%   title_t: Title of the Figure (Actually saving without title)
%   Format: Struct with format
%   Dir: Struct with Directories
%   QEsummary: Data base with income dynamics statistics
%   Countries: List of the countries you with regression output
% Name of the Figure = [name_figure code_plot]
% 
%% Outputs:
%   Figure 2 stored in the corresponding folder    

%Housekeeping
name_figure_store=name_figure;

%Get data and sort it
[P9010_coef,I]=sort(table2array(P9010.coef));
P9050_coef=table2array(P9050.coef);
P9050_coef=P9050_coef(I);
P5010_coef=table2array(P5010.coef);
P5010_coef=P5010_coef(I);
Countries2= Countries(I);

%Define labels for the Figure
y_label=['Average Annual Change (log percent)'];
x_label=['Countries'];

%Create Figure
f1 = figure('Color',[1 1 1], 'Position',Format.L3_figsize,'defaultAxesColorOrder',[[0 0 0]; [0 0 0]]);
%Apply Margins
subaxis(1,1,1,'SpacingHoriz', Format.L3_spaceH, ...
        'SpacingVert',Format.L3_spaceV, 'PL',Format.L3_padding,'PR',Format.L3_padding,'mt',...
        Format.L3_marTop,'mb',Format.L3_marBot,'ML',Format.L3_marginL,'MR',Format.L3_marginR);

%Plot Data
x = categorical(Countries2);
vals = [P9010_coef; P9050_coef;P5010_coef];
b = bar(vals',0.95);
set(gca,'xticklabel',x)



%Format Graph colors
b(1).FaceColor = Format.L3_fillcolors{1};
b(1).EdgeColor = Format.L3_Edgecolors{1};
b(2).FaceColor = Format.L3_fillcolors{2};
b(2).EdgeColor = Format.L3_Edgecolors{2};
b(3).FaceColor = Format.L3_fillcolors{3};
b(3).EdgeColor = Format.L3_Edgecolors{3};

%Format y-axis
ylim([-4.2 2.5])
Y_ticks= [-4 -2 0 2];
yticks(Y_ticks)
set(gca,'FontSize',Format.L3_FontSize_axis_2,'XGrid','on','YGrid','on');
y=ylabel(y_label,'FontSize',Format.L3_FontSize_axis);

%Format x-axis
ax = gca;
ax.LineWidth=1;

%Include Legend
l_legend=["P90-P10" "P90-P50" "P50-P10" ];
legend(l_legend,'Location','southoutside','FontSize',Format.L3_FontSize_legend,'Box','off',NumColumns=3);


name_figure=[name_figure_store];

%Storing Files
Storing_figures;

cd(Dir.Main_directory)
close all
end
