
function Y= Figure_5_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir)
%This Code replicate Figures 4 from the paper
%%   Inputs:
%   Stats: Data base with income dynamics statistics 
%   Density: Data base with density
%   GDP_growth: Data base with GDP Growth 
%   name: Country Code
%   name_figure: Name of the Figure (See below)
%   Figure_name: Figure Number (Creates the directory)
%   code_plot: Name of the Figure (See below)
%   variable_1: Variables general to all figures
%   variables: Variables to plot (Specific for each figure)
%   age: Age-Group in the figures
%   gender: Gender in the figures
%   title_t: Title of the Figure (Actually saving without title)
%   Format: Struct with format
%   Dir: Struct with Directories
%              Name of the Figure = [name_figure code_plot]
%% Outputs:
%   Figure 5 stored in the corresponding folder    

%Housekeeping
name_figure_store=name_figure;

%Graph specific
%Data Selector: Graph specific
logic_1=Density.country==[name] & Density.age==[age] & Density.year== 2005; 
data_select=Density(logic_1,[variable_1,variables]);
logic_1_bis= Stats.country==[name] & Stats.age==[age] & Stats.year== 2005;
variables_2= ["std_res_1yr_log_chg" "skew_res_1yr_log_chg" "kurt_res_1yr_log_chg" ];
data_select_stats= Stats(logic_1_bis,[variable_1,variables_2]);

%Creating Log Density
logic_v=data_select.dens_bin_res_1yr_log_chg_distr>0;
data_select.Log_density=NaN*data_select.dens_bin_res_1yr_log_chg_distr;
data_select.Log_density(logic_v)=log(data_select.dens_bin_res_1yr_log_chg_distr(logic_v));
data_select.Density=data_select.dens_bin_res_1yr_log_chg_distr;

%Define labels for the Figure
y_label=['Density'];
x_label=['Annual Change in Log Income'];

%Create Figure
f1 = figure('Color',[1 1 1], 'Position',Format.DD_figsize,'defaultAxesColorOrder',[[0 0 0]; [0 0 0]]);
%Apply Margins
subaxis(1,1,1,'SpacingHoriz', Format.DD_spaceH, ...
        'SpacingVert',Format.DD_spaceV, 'PL',Format.DD_padding,'PR',Format.DD_padding,'mt',...
        Format.DD_marTop,'mb',Format.DD_marBot,'ML',Format.DD_marginL,'MR',Format.DD_marginR);

%Select Data by gender and get statistics
logic_b=data_select.gender==gender(1);
logic_b_bis= data_select_stats.gender==gender(1);
sd_c=table2array(data_select_stats(logic_b_bis,[variables_2(1)]));
skew_c=table2array(data_select_stats(logic_b_bis,[variables_2(2)]));
kurt_c=table2array(data_select_stats(logic_b_bis,[variables_2(3)]));

y1=table2array(data_select(logic_b,["Density"]));
x1=table2array(data_select(logic_b,[variables(1)]));

%Restrict X for the analisis
logic_c = ~isnan(y1);
logic_c_2 = x1<=4 & x1>=-4;
logic_c=logical(logic_c.*logic_c_2);

%Creates Variables -> Keeping only Non missing and between -4:4
y1=y1(logic_c);
x1=x1(logic_c);
X=[ones(size(x1)),x1];

%Selection Variables and regressions
logic_left= x1<-1 & x1>=-4; 
logic_rigth= x1>1 & x1<=4 ;

%Get Pareto Tail index
%Left tail
beta_left=inv((X(logic_left,:)'*X(logic_left,:)))*X(logic_left,:)'*y1(logic_left);
% Right rail
beta_right=inv((X(logic_rigth,:)'*X(logic_rigth,:)))*X(logic_rigth,:)'*y1(logic_rigth);
% Get linear regresion line
y_hat_left=X*beta_left;
y_hat_left(~logic_left)=NaN;
y_hat_right=X*beta_right;
y_hat_right(~logic_rigth)=NaN;

%Get Normal Distribution
Nor= pdf('normal',x1,0,sd_c);

%Constraint axis normal distribution
logic_norm= Nor>=exp(-8) ;
Nor(~logic_norm)=NaN;

%Plot
Y=[y1,Nor,NaN*zeros(size(Nor)),NaN*zeros(size(Nor)),NaN*zeros(size(Nor)),NaN*zeros(size(Nor))];
p2=plot(x1,Y);
 for linei = 1:size(Y,2)
        set(p2(linei),'LineStyle',Format.DD_styles{linei});
        set(p2(linei),'color',Format.DD_colors{linei});
        set(p2(linei),'linewidth',Format.DD_widths{linei});
        set(p2(linei),'marker',  'none');
 end
%Format lables
set(gca,'FontSize',Format.DD_FontSize_axis_2,'XGrid','on','YGrid','on');
x=xlabel(x_label,'FontSize',Format.DD_FontSize_axis,'Interpreter','latex','FontWeight','bold');
y=ylabel(y_label,'FontSize',Format.DD_FontSize_axis,'Interpreter','latex','FontWeight','bold');
set(y, 'Units', 'Normalized', 'Position', [-0.075, 0.5, 0]);
set(x, 'Units', 'Normalized', 'Position', [0.5, -0.09, 0]);

%y-axis
ylim([exp(-10.5) 4.5]);
yticks([0 1 2  3  4  5 ])

%x-axis
ax = gca;
ax.LineWidth=1;
ax.XTick=[-4 -3 -2 -1 0 1 2 3 4 ];
xlim([-4.2 4.2]);

% Create legend
a=['$N$(0,' num2str(round(sd_c,2),2) '$^2$)'];
b=['Skewness: ' num2str(round(skew_c,2),2) ];
c=['Kurtosis: ' num2str(round(kurt_c,3),4) ];
h=[' '];

%Legend
legendinfo=legend(p2);
l_legend=["Data Density",a,h,h,b,c];
legend(l_legend,'Location','NorthWest','FontSize',Format.DD_FontSize_legend,'Box','off',Interpreter='latex', NumColumns=3);
name_figure=[ name_figure_store '-' char(gender(1))];


%Storing Files
Storing_figures;




%% Same graph for females
%Create Figure
f1 = figure('Color',[1 1 1], 'Position',Format.DD_figsize,'defaultAxesColorOrder',[[0 0 0]; [0 0 0]]);
%Apply Margins
subaxis(1,1,1,'SpacingHoriz', Format.DD_spaceH, ...
        'SpacingVert',Format.DD_spaceV, 'PL',Format.DD_padding,'PR',Format.DD_padding,'mt',...
        Format.DD_marTop,'mb',Format.DD_marBot,'ML',Format.DD_marginL,'MR',Format.DD_marginR);

%Select Data by gender and get statistics
logic_b=data_select.gender==gender(2);
logic_b_bis= data_select_stats.gender==gender(2);
sd_c=table2array(data_select_stats(logic_b_bis,[variables_2(1)]));
skew_c=table2array(data_select_stats(logic_b_bis,[variables_2(2)]));
kurt_c=table2array(data_select_stats(logic_b_bis,[variables_2(3)]));

y1=table2array(data_select(logic_b,["Density"]));
x1=table2array(data_select(logic_b,[variables(1)]));

%Restrict X for the analisis
logic_c = ~isnan(y1);
logic_c_2 = x1<=4 & x1>=-4;
logic_c=logical(logic_c.*logic_c_2);

%Creates Variables -> Keeping only Non missing and between -4:4
y1=y1(logic_c);
x1=x1(logic_c);
X=[ones(size(x1)),x1];

%Selection Variables and regressions
logic_left= x1<-1 & x1>=-4; 
logic_rigth= x1>1 & x1<=4 ;

%Get Pareto Tail index
%Left tail
beta_left=inv((X(logic_left,:)'*X(logic_left,:)))*X(logic_left,:)'*y1(logic_left);
% Right rail
beta_right=inv((X(logic_rigth,:)'*X(logic_rigth,:)))*X(logic_rigth,:)'*y1(logic_rigth);
% Get linear regresion line
y_hat_left=X*beta_left;
y_hat_left(~logic_left)=NaN;
y_hat_right=X*beta_right;
y_hat_right(~logic_rigth)=NaN;

%Get Normal Distribution
Nor= pdf('normal',x1,0,sd_c);

%Constraint axis normal distribution
logic_norm= Nor>=exp(-8) ;
Nor(~logic_norm)=NaN;

%Plot
Y=[y1,Nor,NaN*zeros(size(Nor)),NaN*zeros(size(Nor)),NaN*zeros(size(Nor)),NaN*zeros(size(Nor))];
p2=plot(x1,Y);
 for linei = 1:size(Y,2)
        set(p2(linei),'LineStyle',Format.DD_styles{linei});
        set(p2(linei),'color',Format.DD_colors{linei});
        set(p2(linei),'linewidth',Format.DD_widths{linei});
        set(p2(linei),'marker',  'none');
 end
%Format lables
set(gca,'FontSize',Format.DD_FontSize_axis_2,'XGrid','on','YGrid','on');
x=xlabel(x_label,'FontSize',Format.DD_FontSize_axis,'Interpreter','latex','FontWeight','bold');
y=ylabel(y_label,'FontSize',Format.DD_FontSize_axis,'Interpreter','latex','FontWeight','bold');
set(y, 'Units', 'Normalized', 'Position', [-0.075, 0.5, 0]);
set(x, 'Units', 'Normalized', 'Position', [0.5, -0.09, 0]);

%y-axis
ylim([exp(-10.5) 4.5]);
yticks([0 1 2  3  4  5 ])

%x-axis
ax = gca;
ax.LineWidth=1;
ax.XTick=[-4 -3 -2 -1 0 1 2 3 4 ];
xlim([-4.2 4.2]);

% Create legend
a=['$N$(0,' num2str(round(sd_c,2),2) '$^2$)'];
b=['Skewness: ' num2str(round(skew_c,2),2) ];
c=['Kurtosis: ' num2str(round(kurt_c,3),4) ];
h=[' '];

legendinfo=legend(p2);
l_legend=["Data Density",a,h,h,b,c];
legend(l_legend,'Location','NorthWest','FontSize',Format.DD_FontSize_legend,'Box','off',Interpreter='latex', NumColumns=3);
name_figure=[ name_figure_store '-' char(gender(2))];

%Storing Files
Storing_figures;



cd(Dir.Main_directory)
close all
end
