
function Y= Figure_7_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir)
%This Code replicate Figures 6 from the paper
%%   Inputs:
%   Stats: Data base with income dynamics statistics 
%   Density: Data base with density
%   GDP_growth: Data base with GDP Growth 
%   name: Country Code
%   name_figure: Name of the Figure (See below)
%   Figure_name: Figure Number (Creates the directory)
%   code_plot: Name of the Figure (See below)
%   variable_1: Variables general to all figures
%   variables: Variables to plot (Specific for each figure)
%   age: Age-Group in the figures
%   gender: Gender in the figures
%   title_t: Title of the Figure (Actually saving without title)
%   Format: Struct with format
%   Dir: Struct with Directories
%              Name of the Figure = [name_figure code_plot]
%% Outputs:
%   Figure 6 stored in the corresponding folder   

%Housekeeping
name_figure_store=name_figure;

%Graph specific
%Data Selector: Graph specific
logic_1=Stats.country==[name] & Stats.age==[age];
data_select=Stats(logic_1,[variable_1,variables]);
data_select_gr=GDP_growth(logic_1,:);

%Define labels for the Figure
y_label=['Standard Dev. of $g^1$'];

if string(name)==string('UK')

y_label=['P90-P10 Differential of $g^1$'];

end

x_label=[];
name_gdp=['GDP Growth'];
l_legend=["Male" "Female"];

%Create Figure
f1 = figure('Color',[1 1 1], 'Position',Format.P_figsize,'defaultAxesColorOrder',[[0 0 0]; [0 0 0]]);
%Apply Margins
subaxis(1,1,1,'SpacingHoriz', Format.P_spaceH, ...
        'SpacingVert',Format.P_spaceV, 'PL',Format.P_padding,'PR',Format.P_padding,'mt',...
        Format.P_marTop,'mb',Format.P_marBot,'ML',Format.P_marginL_2,'MR',Format.P_marginR_2);

%Select Data by gender and get statistics
logic_b=data_select.gender==gender(1);
y1=table2array(data_select(logic_b,[variables]));
x1=table2array(data_select(logic_b,["year"]));
logic_c=data_select.gender==gender(2);
y1_b=table2array(data_select(logic_c,[variables]));
x1_b=table2array(data_select(logic_c,["year"]));


Y=[y1 y1_b];
p2=plot(x1,Y);
 for linei = 1:size(Y,2)
        set(p2(linei),'LineStyle',Format.styles{linei});
        set(p2(linei),'color',Format.colors{linei});
        set(p2(linei),'linewidth',Format.widths{linei});
        set(p2(linei),'marker',   Format.marker{linei});
        set(p2(linei),'MarkerFaceColor', Format.fillcolors{linei});
        set(p2(linei),'MarkerEdgeColor', Format.Edgecolors{linei}) ;
        set(p2(linei),'MarkerSize', Format.marker_size{linei}) ;
 end

%Format Labels
set(gca,'FontSize',Format.P_FontSize_axis_2,'XGrid','on','YGrid','on');
x=xlabel(x_label,'FontSize',Format.P_FontSize_axis,'Interpreter','latex','FontWeight','bold');
y=ylabel(y_label,'FontSize',Format.P_FontSize_axis,'Interpreter','latex','FontWeight','bold');
set(y, 'Units', 'Normalized', 'Position', [-0.098, 0.5, 0]);
set(x, 'Units', 'Normalized', 'Position', [0.5, -0.09, 0]);

%Format y-axis
ylim([0.35 0.85])

if string(name)==string('BRA')

ylim([0.35 0.95])

end

if string(name)==string('UK')

ylim([0.30 0.85])

end


yticks([0.35 0.45 0.55 0.65 0.75 0.85 0.95])

%Format x-axis
ax = gca;
ax.LineWidth=1;
logic_nan=~isnan(Y);
x_min=min(x1(logic_nan(:,1)))-1;
x_max=max(x1(logic_nan(:,1)))+1;
ax.XTick=[1975 1980 1985 1990 1995 2000 2005 2010 2015 2020];
xlim([x_min,x_max])

if string(name)==string('UK')

ylim([0.30 0.85])
ax.XTick=[1975  1985  1995  2005  2015 ];
end

%Apply Legend to the first figure
if string(name)==string('ARG')
    %Legend
l_legend=["Male" "Female"];
legend(l_legend,'Location','best','FontSize',Format.P_FontSize_legend,'Box','on',Interpreter='latex');
end

name_figure=[ name_figure_store];

%Storing Files
Storing_figures;

cd(Dir.Main_directory)
close all
end
