
function Y= Figure_8_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir)
%This Code replicate Figures 7 from the paper
%%   Inputs:
%   Stats: Data base with income dynamics statistics 
%   Density: Data base with density
%   GDP_growth: Data base with GDP Growth 
%   name: Country Code
%   name_figure: Name of the Figure (See below)
%   Figure_name: Figure Number (Creates the directory)
%   code_plot: Name of the Figure (See below)
%   variable_1: Variables general to all figures
%   variables: Variables to plot (Specific for each figure)
%   age: Age-Group in the figures
%   gender: Gender in the figures
%   title_t: Title of the Figure (Actually saving without title)
%   Format: Struct with format
%   Dir: Struct with Directories
%              Name of the Figure = [name_figure code_plot]
%% Outputs:
%   Figure 7 stored in the corresponding folder   

%Housekeeping
name_figure_store=name_figure;

%Graph specific
%Data Selector: Graph specific
logic_1=Stats.country==[name] & Stats.age==[age];
data_select=Stats(logic_1,[variable_1,variables]);
data_select_gr=GDP_growth(logic_1,:);

%Define labels for the Figure
y_label=['Kelley Skewness of $g^1$'];
x_label=[];
name_gdp=['GDP Growth'];

for j=1:length(gender)
%Create Figure
f1 = figure('Color',[1 1 1], 'Position',Format.P_figsize,'defaultAxesColorOrder',[[0 0 0]; [0 0 0]]);
%Apply Margins
subaxis(1,1,1,'SpacingHoriz', Format.P_spaceH, ...
        'SpacingVert',Format.P_spaceV, 'PL',Format.P_padding,'PR',Format.P_padding,'mt',...
        Format.P_marTop,'mb',Format.P_marBot,'ML',Format.P_marginL,'MR',Format.P_marginR);

%Select Gender
logic_b=data_select.gender==gender(j);
%Select variables to plot
y1=table2array(data_select(logic_b,[variables]));
%Get Missing
MIS=ismissing(y1);
%Get X asis
x1=table2array(data_select(logic_b,["year"]));

%Select GDP
y11=table2array(data_select_gr(logic_b,["F1_per_capita_ln_gdp_growth"]));
%Get Missing
MIS2=ismissing(y11);

%Plot non mising only
mis_fin=~logical(~MIS2.*~MIS);

%Normalization
y1b=NaN*zeros(length(y11),1);
y1b(~mis_fin)=(y11(~mis_fin)-mean(y11(~mis_fin)))./std(y11(~mis_fin));
x11=table2array(data_select_gr(logic_b,["year"]));

%Plot
Y=[y1];
yyaxis left;
p2=plot(x1,Y);
 for linei = 1:size(Y,2)
        set(p2(linei),'LineStyle',Format.styles{linei});
        set(p2(linei),'color',Format.colors{linei});
        set(p2(linei),'linewidth',Format.widths{linei});
        set(p2(linei),'marker',   Format.marker{linei});
        set(p2(linei),'MarkerFaceColor', Format.fillcolors{linei});
        set(p2(linei),'MarkerEdgeColor', Format.Edgecolors{linei}) ;
        set(p2(linei),'MarkerSize', Format.marker_size{linei}) ;
 end
%Format Labels
set(gca,'FontSize',Format.P_FontSize_axis_2,'XGrid','on','YGrid','on');
x=xlabel(x_label,'FontSize',Format.P_FontSize_axis,'Interpreter','latex','FontWeight','bold');
y=ylabel(y_label,'FontSize',Format.P_FontSize_axis,'Interpreter','latex','FontWeight','bold');
set(y, 'Units', 'Normalized', 'Position', [-0.09, 0.5, 0]);
set(x, 'Units', 'Normalized', 'Position', [0.5, -0.09, 0]);

%Format y-axis
ylim(y_axis_format(Y));

%Format x-axis
ax = gca;
ax.LineWidth=1;


yyaxis right;
p3=plot(x11,y1b);
 for linei = 1:1
        set(p3(linei),'LineStyle',Format.styles_gdp{linei});
        set(p3(linei),'color',Format.colors_gdp{linei});
        set(p3(linei),'linewidth',Format.widths_gdp{linei});
        set(p3(linei),'marker',   Format.marker_gdp{linei});
        set(p3(linei),'MarkerFaceColor', Format.fillcolors_gdp{linei});
        set(p3(linei),'MarkerEdgeColor', Format.Edgecolors_gdp{linei}) ;
 end
%Format GDP  
gdp_format;

% Format x-axis
ax = gca;
ax.LineWidth=1;
logic_nan=~isnan(Y);
x_min=min(x1(logic_nan))-1;
x_max=max(x1(logic_nan))+1;
ax.XTick=[1975 1980 1985 1990 1995 2000 2005 2010 2015 2020];
xlim([x_min,x_max]);

if string(name)==string('UK')
ax.XTick=[1975  1985  1995  2005  2015 ];
end

%Apply Legend to the first figure
if string(name)==string('ARG')
    %Legend
l_legend=["Kelley skewness" "GDP growth"];
legend(l_legend,'Location','best','FontSize',Format.P_FontSize_legend,'Box','on',Interpreter='latex');
end

name_figure=[ name_figure_store '-' char(gender(j))];

%Storing Files
Storing_figures;

end

cd(Dir.Main_directory)
close all
end
