
function Y= Figure_A_1_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Rank)
%This Code replicate Figures A.1 from the paper
%%   Inputs:
%   Stats: Data base with income dynamics statistics 
%   Density: Data base with density
%   GDP_growth: Data base with GDP Growth 
%   name: Country Code
%   name_figure: Name of the Figure (See below)
%   Figure_name: Figure Number (Creates the directory)
%   code_plot: Name of the Figure (See below)
%   variable_1: Variables general to all figures
%   variables: Variables to plot (Specific for each figure)
%   age: Age-Group in the figures
%   gender: Gender in the figures
%   title_t: Title of the Figure (Actually saving without title)
%   Format: Struct with format
%   Dir: Struct with Directories
%   Rank: Data base with Statistics by skill 
%              Name of the Figure = [name_figure code_plot]
%% Outputs:
%   Figure A.1 stored in the corresponding folder 
%Housekeeping
name_figure_store=name_figure;

%Graph specific
%Data Selector: Graph specific
logic_1=Rank.country==[name] & Rank.year== 9999;
data_select=Rank(logic_1,[variable_1,variables]);

%Define labels for the Figure
y_label=['P90-P10 Differential of $g^5$'];
if string(name) =='UK'
% For UK g1
 y_label=['P90-P10 Differential of $g^1$'];
end

x_label=['Quantiles of Permanet Income $P_{i t-1}$'];
name_gdp=['GDP Growth'];

for j=1:length(gender)
%Create Figure
f1 = figure('Color',[1 1 1], 'Position',Format.P_figsize,'defaultAxesColorOrder',[[0 0 0]; [0 0 0]]);
%Apply Margins
subaxis(1,1,1,'SpacingHoriz', Format.P_spaceH, ...
        'SpacingVert',Format.P_spaceV, 'PL',Format.P_padding,'PR',Format.P_padding,'mt',...
        Format.P_marTop,'mb',Format.P_marBot,'ML',Format.P_marginL,'MR',Format.P_marginR);

% Data selection
logic_b=data_select.gender==gender(j);
logic_b1=data_select.gender==gender(j) & data_select.age==age(1);
logic_b2=data_select.gender==gender(j) & data_select.age==age(2);
logic_b3=data_select.gender==gender(j) & data_select.age==age(3);

y1_1=table2array(data_select(logic_b1,[variables]));
x1_1=table2array(data_select(logic_b1,["rank_permanent_inc"]));
y1_2=table2array(data_select(logic_b2,[variables]));
x1_2=table2array(data_select(logic_b2,["rank_permanent_inc"]));
y1_3=table2array(data_select(logic_b3,[variables]));
x1_3=table2array(data_select(logic_b3,["rank_permanent_inc"]));

logic_b1_1=~isnan(y1_1);
logic_b2_1=~isnan(y1_2);
logic_b3_1=~isnan(y1_3);

%Plot
Y=[y1_1,y1_2,y1_3];
p2=plot(x1_1(logic_b1_1),y1_1(logic_b1_1),x1_2(logic_b2_1),y1_2(logic_b2_1),x1_3(logic_b3_1),y1_3(logic_b3_1));
 for linei = 1:size(Y,2)
        set(p2(linei),'LineStyle',Format.P_styles{linei});
        set(p2(linei),'color',Format.P_colors{linei});
        set(p2(linei),'linewidth',Format.P_widths{linei});
        set(p2(linei),'marker',   Format.P_marker{linei});
        set(p2(linei),'MarkerFaceColor', Format.P_fillcolors{linei});
        set(p2(linei),'MarkerEdgeColor', Format.P_Edgecolors{linei}) ;
        set(p2(linei),'MarkerSize', Format.P_marker_size{linei}) ;     
 end
%Format Labels
set(gca,'FontSize',Format.P_FontSize_axis_2_long,'XGrid','on','YGrid','on');
x=xlabel(x_label,'FontSize',Format.P_FontSize_axis_long,'Interpreter','latex','FontWeight','bold');
y=ylabel(y_label,'FontSize',Format.P_FontSize_axis_long_2,'Interpreter','latex','FontWeight','bold');
set(y, 'Units', 'Normalized', 'Position', [-0.075, 0.5, 0]);
set(x, 'Units', 'Normalized', 'Position', [0.5, -0.09, 0]);


%Format y-axis
ylim([0.2 3])
yticks([0.5  1  1.5 2 2.5 3 ])
logic_nan=~isnan(Y);

%Format x-axis
ax = gca;
ax.LineWidth=1;
x_min=0-2;
x_max=100+2;
ax.XTick=[0 10 20 30 40 50 60 70 80 90 100];
xlim([x_min,x_max])


%Apply Legend to the first figure
if string(name)==string('ARG')
    %Legend
l_legend=["[25-34]" "[35-44]" "[45-55]"];
legend(l_legend,'Location','northeast','FontSize',Format.P_FontSize_legend,'Box','on',Interpreter='latex');
end


name_figure=[ name_figure_store '-' char(gender(j))];

%Storing Files
Storing_figures;
end

cd(Dir.Main_directory)
close all
end
