
function Y= Regresion_table_3(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Countries,Countries_name)
%This Code replicate Table 2 from the paper
%%   Inputs:
%   Stats: Data base with income dynamics statistics 
%   Density: Data base with density
%   GDP_growth: Data base with GDP Growth 
%   name: Country Code
%   name_figure: Name of the Figure (See below)
%   Figure_name: Figure Number (Creates the directory)
%   code_plot: Name of the Figure (See below)
%   variable_1: Variables general to all figures
%   variables: Variables to plot (Specific for each figure)
%   age: Age-Group in the figures
%   gender: Gender in the figures
%   title_t: Title of the Figure (Actually saving without title)
%   Format: Struct with format
%   Dir: Struct with Directories
%              Name of the Figure = [name_figure code_plot]
%   Countries: Vector with countries name

%% Outputs:
%   Regression coeficietns by country are saved in 'Table_3.xlsx'  



%Storing results

N=3; %Number of Exogenous variables
M=length(variables); %Number of LHS
F=length(gender); %Number gender we want
C=length(Countries); %Number of countries

% High dimentional matrix to store results
Big_beta=NaN*zeros(N,M,F,length(Countries));
Big_t_statistic=NaN*zeros(N,M,F,length(Countries));
Big_sd_beta=NaN*zeros(N,M,F,length(Countries)); 
Big_N=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_t_init=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_t_end=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_std_gdp=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_mean_gdp=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_R2_adjusted=NaN*zeros(N,M,F,length(Countries)); % Store R2
Big_R2_ordinary=NaN*zeros(N,M,F,length(Countries)); % Store Ordinary R2

Success=zeros(length(Countries),M);%Store Regression falg 
for i=1:length(Countries) 
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];

%Data Selector: Reg specific
logic_1=Stats.country==[name] & Stats.age==[age];
data_select=Stats(logic_1,[variable_1,variables]);
data_select_gr=GDP_growth(logic_1,:);

try
%Loop in Gender
for j=1:length(gender)
%Generate Logicals for conditioning
logic_2=data_select.gender==gender(j);
%Get LHS 
Y=[table2array(data_select(logic_2,variables))];
[logic_3]=ismissing(Y);

%Generate X$
x=data_select_gr.F1_per_capita_ln_gdp_growth(logic_2);
years=data_select_gr.year(logic_2);
[logic_4]=ismissing(x);

logic_final=logical(~logic_3.*~logic_4);

for m=1:size(Y,2)
try
%Get same data than Y for normalization
x_=x(logic_final(:,m),:);
Y_=Y(logic_final(:,m),m);

a=mean(x_);
b=std(x_);
x_=(x_-mean(x_))/std(x_);
J=length(x_);
trend=linspace(1,J,J);
% Add a constant to the Reg
X=[ones(length(x_),1),x_,trend'];


% Comment: in HAC command, Bandwidth = lag()+1 
% where lag is the comand in stata. 
% example: bandwidth = 4 --> lag(3) in stata)

[EstCoeffCov,se,coeff] = hac(X,Y_,'Intercept',false,'Display', 'off','Type','HAC','bandwidth',4);
warning('off','all');
mdl = fitlm(X,Y_);


%Store Coefficients
Big_beta(:,m,j,i)=coeff*100;
Big_sd_beta(:,m,j,i)=se*100;
Big_t_statistic(:,m,j,i)=coeff./se;

%Store R2
Big_R2_adjusted(:,m,j,i)=mdl.Rsquared.Adjusted;
%Store R2
Big_R2_ordinary(:,m,j,i)=mdl.Rsquared.Ordinary;


Big_N(:,m,j,i)=length(x_);
Big_t_init(:,m,j,i)=min(years(logic_final(:,m)));
Big_t_end(:,m,j,i)=max(years(logic_final(:,m)));
Big_mean_gdp(:,m,j,i)=a;
Big_std_gdp(:,m,j,i)=b;

ss= char(variables(m)) ;
to_show=['Regression for Country ' name ' and variable ' ss ' was Succesful'];   
display(to_show);
Success(i,m)=1;
catch
ss= char(variables(m)) ;
to_show=['Regression for Country ' name ' and variable ' ss ' was skipped'];   
display(to_show);
Success(i,m)=0;
end

end

end
% to_show=['Regression for Country ' name ' was Succesful'];   
% display(to_show);
% Success(i,1)=1;
catch
to_show=['Regression for Country ' name ' was skipped'];   
display(to_show);    
Success(i,1)=0;
end


end


%% Step 3: Storing Results: Keeping with coeficient on log(gdp_t)-log(gdp_t-1)

y_Kellew.coef=array2table(squeeze(Big_beta(2,1,:,:)),'VariableName',Countries);
y_P9010.coef=array2table(squeeze(Big_beta(2,2,:,:)),'VariableName',Countries);
y_P9050.coef=array2table(squeeze(Big_beta(2,3,:,:)),'VariableName',Countries);
y_P5010.coef=array2table(squeeze(Big_beta(2,4,:,:)),'VariableName',Countries);
y_crow.coef=array2table(squeeze(Big_beta(2,5,:,:))/100,'VariableName',Countries);


y_Kellew.sd=array2table(squeeze(Big_sd_beta(2,1,:,:)),'VariableName',Countries);
y_P9010.sd=array2table(squeeze(Big_sd_beta(2,2,:,:)),'VariableName',Countries);
y_P9050.sd=array2table(squeeze(Big_sd_beta(2,3,:,:)),'VariableName',Countries);
y_P5010.sd=array2table(squeeze(Big_sd_beta(2,4,:,:)),'VariableName',Countries);
y_crow.sd=array2table(squeeze(Big_sd_beta(2,5,:,:))/100,'VariableName',Countries);


y_Kellew.t_stat=array2table(squeeze(Big_t_statistic(2,1,:,:)),'VariableName',Countries);
y_P9010.t_stat=array2table(squeeze(Big_t_statistic(2,2,:,:)),'VariableName',Countries);
y_P9050.t_stat=array2table(squeeze(Big_t_statistic(2,3,:,:)),'VariableName',Countries);
y_P5010.t_stat=array2table(squeeze(Big_t_statistic(2,4,:,:)),'VariableName',Countries);
y_crow.t_stat=array2table(squeeze(Big_t_statistic(2,5,:,:)),'VariableName',Countries);

y_Kellew.N=array2table(squeeze(Big_N(2,1,:,:)),'VariableName',Countries);
y_P9010.N=array2table(squeeze(Big_N(2,2,:,:)),'VariableName',Countries);
y_P9050.N=array2table(squeeze(Big_N(2,3,:,:)),'VariableName',Countries);
y_P5010.N=array2table(squeeze(Big_N(2,4,:,:)),'VariableName',Countries);
y_crow.N=array2table(squeeze(Big_N(2,5,:,:)),'VariableName',Countries);

y_Kellew.t_init=array2table(squeeze(Big_t_init(2,1,:,:)),'VariableName',Countries);
y_P9010.t_init=array2table(squeeze(Big_t_init(2,2,:,:)),'VariableName',Countries);
y_P9050.t_init=array2table(squeeze(Big_t_init(2,3,:,:)),'VariableName',Countries);
y_P5010.t_init=array2table(squeeze(Big_t_init(2,4,:,:)),'VariableName',Countries);
y_crow.t_init=array2table(squeeze(Big_t_init(2,5,:,:)),'VariableName',Countries);

y_Kellew.t_end=array2table(squeeze(Big_t_end(2,1,:,:)),'VariableName',Countries);
y_P9010.t_end=array2table(squeeze(Big_t_end(2,2,:,:)),'VariableName',Countries);
y_P9050.t_end=array2table(squeeze(Big_t_end(2,3,:,:)),'VariableName',Countries);
y_P5010.t_end=array2table(squeeze(Big_t_end(2,4,:,:)),'VariableName',Countries);
y_crow.t_end=array2table(squeeze(Big_t_end(2,5,:,:)),'VariableName',Countries);

y_Kellew.mean_gdp=array2table(squeeze(Big_mean_gdp(2,1,:,:)),'VariableName',Countries);
y_P9010.mean_gdp=array2table(squeeze(Big_mean_gdp(2,2,:,:)),'VariableName',Countries);
y_P9050.mean_gdp=array2table(squeeze(Big_mean_gdp(2,3,:,:)),'VariableName',Countries);
y_P5010.mean_gdp=array2table(squeeze(Big_mean_gdp(2,4,:,:)),'VariableName',Countries);
y_crow.mean_gdp=array2table(squeeze(Big_mean_gdp(2,5,:,:)),'VariableName',Countries);

y_Kellew.std_gdp=array2table(squeeze(Big_std_gdp(2,1,:,:)),'VariableName',Countries);
y_P9010.std_gdp=array2table(squeeze(Big_std_gdp(2,2,:,:)),'VariableName',Countries);
y_P9050.std_gdp=array2table(squeeze(Big_std_gdp(2,3,:,:)),'VariableName',Countries);
y_P5010.std_gdp=array2table(squeeze(Big_std_gdp(2,4,:,:)),'VariableName',Countries);
y_crow.std_gdp=array2table(squeeze(Big_std_gdp(2,5,:,:)),'VariableName',Countries);

y_Kellew.R2_adj=array2table(squeeze(Big_R2_adjusted(2,1,:,:)),'VariableName',Countries);
y_P9010.R2_adj=array2table(squeeze(Big_R2_adjusted(2,2,:,:)),'VariableName',Countries);
y_P9050.R2_adj=array2table(squeeze(Big_R2_adjusted(2,3,:,:)),'VariableName',Countries);
y_P5010.R2_adj=array2table(squeeze(Big_R2_adjusted(2,4,:,:)),'VariableName',Countries);
y_crow.R2_adj=array2table(squeeze(Big_R2_adjusted(2,5,:,:)),'VariableName',Countries);

y_Kellew.R2_ord=array2table(squeeze(Big_R2_ordinary(2,1,:,:)),'VariableName',Countries);
y_P9010.R2_ord=array2table(squeeze(Big_R2_ordinary(2,2,:,:)),'VariableName',Countries);
y_P9050.R2_ord=array2table(squeeze(Big_R2_ordinary(2,3,:,:)),'VariableName',Countries);
y_P5010.R2_ord=array2table(squeeze(Big_R2_ordinary(2,4,:,:)),'VariableName',Countries);
y_crow.R2_ord=array2table(squeeze(Big_R2_ordinary(2,5,:,:)),'VariableName',Countries);



%% Exporting results
cd(Dir.Output_Reg)

%% Save Kelley Skewness
title_coef=["Kelley skewness coef"];
Sheet_name=["Kellew_Skew"];

title_sd=["Coeficient S.E."];
title_t_stat=["Coeficient t-stat"];
save_name=['Table_3.xlsx'];

DATA=y_Kellew;
save_results_excel(title_coef,title_sd,title_t_stat,Sheet_name,save_name,DATA);

%% Save P9050
title_coef=["P9050 coef"];
Sheet_name=["P9050"];

DATA=y_P9050;
save_results_excel(title_coef,title_sd,title_t_stat,Sheet_name,save_name,DATA);

%% Save P5010
title_coef=["P5010 coef"];
Sheet_name=["P5010"];

DATA=y_P5010;
save_results_excel(title_coef,title_sd,title_t_stat,Sheet_name,save_name,DATA);

%% Save P9010
title_coef=["P9010 coef"];
Sheet_name=["P9010"];

DATA=y_P9010;
save_results_excel(title_coef,title_sd,title_t_stat,Sheet_name,save_name,DATA);

%% Save Crow_Kurtosis
title_coef=["Crow-Kurtosis coef"];
Sheet_name=["Crow_Kurtosis"];

DATA=y_crow;
save_results_excel(title_coef,title_sd,title_t_stat,Sheet_name,save_name,DATA);

cd(Dir.Main_directory)
end