function [P9010,P9050,P5010,Success]= regresion_trend(Stats,Density,GDP_growth,variable_1,variables,age,gender,Format,Dir,QEsummary,Countries)
%This Code runs the regresions describe in table 2 and store the results
%%   Inputs:
%   Stats: Data base with income dynamics statistics 
%   Density: Data base with density
%   GDP_growth: Data base with GDP Growth 
%   variable_1: Variables general to all figures
%   variables: Variables to regress
%   age: Age-Group in regresion
%   gender: Gender in regresion
%   Format: Struct with format
%   Dir: Struct with Directories
%   QEsummary: Data base with income dynamics statistics
%   Countries: Code List of the countries to run the regression

%% Outputs:
%  P9010 : Structure with Regresions results of P9010 
%  P9050 : Structure with Regresions results of P9050 
%  P5010 : Structure with Regresions results of P5010 
% Success: Output Flag 1 = Regression done 0 = Regression skiped

N=3; %Number of Exogenous variables
M=length(variables); %Number of LHS
F=length(gender); %Number gender we want
C=length(Countries); %Number of countries

% High dimentional matrix to store results
Big_beta=NaN*zeros(N,M,F,length(Countries));
Big_t_statistic=NaN*zeros(N,M,F,length(Countries));
Big_sd_beta=NaN*zeros(N,M,F,length(Countries)); 
Big_N=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_t_init=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_t_end=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_std_gdp=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_mean_gdp=NaN*zeros(N,M,F,length(Countries)); % Store Sample Size
Big_R2_adjusted=NaN*zeros(N,M,F,length(Countries)); % Store R2
Big_R2_ordinary=NaN*zeros(N,M,F,length(Countries)); % Store Ordinary R2

Success=zeros(length(Countries),1);%Store Regression falg 
for i=1:length(Countries)
name=[char(Countries(i))];

%Data Selector: Reg specific
logic_1=QEsummary.country==[name] & QEsummary.age==[age];
data_select=QEsummary(logic_1,[variable_1,variables]);
data_select_gr2=QEsummary(logic_1,["year" "growth_gdp_pc" "per_capita_ln_gdp_growth"]);


try
%Loop in Gender
for j=1:length(gender)
%Generate Logicals for conditioning
logic_2=data_select.gender==gender(j);
%Get LHS 
Y=[table2array(data_select(logic_2,variables))];
[~,logic_3]=rmmissing(Y);

%Generate X$
x=data_select_gr2.per_capita_ln_gdp_growth(logic_2);
years=data_select_gr2.year(logic_2);
[~,logic_4]=rmmissing(x);

logic_final=logical(~logic_3.*~logic_4);
%Get same data than Y for normalization

x=x(logic_final,:);
Y=Y(logic_final,:);

a=mean(x);
b=std(x);
%x=(x-mean(x))/std(x);
J=length(x);
trend=linspace(1,J,J);
% Add a constant to the Reg
X=[ones(length(x),1),x,trend'];

for m=1:size(Y,2)


% Comment: in HAC command, Bandwidth = lag()+1 
% where lag is the comand in stata. 
% example: bandwidth = 4 --> lag(3) in stata)

[EstCoeffCov,se,coeff] = hac(X,Y(:,m),'Intercept',false,'Display', 'off','Type','HAC','bandwidth',4);

mdl = fitlm(X,Y(:,m));


%Store Coefficients
Big_beta(:,m,j,i)=coeff*100;
Big_sd_beta(:,m,j,i)=se*100;
Big_t_statistic(:,m,j,i)=coeff./se;

%Store R2
Big_R2_adjusted(:,m,j,i)=mdl.Rsquared.Adjusted;
%Store R2
Big_R2_ordinary(:,m,j,i)=mdl.Rsquared.Ordinary;


Big_N(:,m,j,i)=length(x);
Big_t_init(:,m,j,i)=min(years(logic_final(:,1)));
Big_t_end(:,m,j,i)=max(years(logic_final(:,1)));
Big_mean_gdp(:,m,j,i)=a;
Big_std_gdp(:,m,j,i)=b;

end

end
to_show=['Regression for Country ' name ' was Succesful'];   
display(to_show);
Success(i,1)=1;
catch
to_show=['Regression for Country ' name ' was skipped'];   
display(to_show);    
Success(i,1)=0;
end

end


%Storing results
P9010.coef=array2table(squeeze(Big_beta(3,1,:,:))','VariableName',Countries);
P9050.coef=array2table(squeeze(Big_beta(3,2,:,:))','VariableName',Countries);
P5010.coef=array2table(squeeze(Big_beta(3,3,:,:))','VariableName',Countries);

P9010.sd=array2table(squeeze(Big_sd_beta(3,1,:,:))','VariableName',Countries);
P9050.sd=array2table(squeeze(Big_sd_beta(3,2,:,:))','VariableName',Countries);
P5010.sd=array2table(squeeze(Big_sd_beta(3,3,:,:))','VariableName',Countries);

P9010.t_stat=array2table(squeeze(Big_t_statistic(3,1,:,:))','VariableName',Countries);
P9050.t_stat=array2table(squeeze(Big_t_statistic(3,2,:,:))','VariableName',Countries);
P5010.t_stat=array2table(squeeze(Big_t_statistic(3,3,:,:))','VariableName',Countries);

P9010.N=array2table(squeeze(Big_N(3,1,:,:))','VariableName',Countries);
P9050.N=array2table(squeeze(Big_N(3,2,:,:))','VariableName',Countries);
P5010.N=array2table(squeeze(Big_N(3,3,:,:))','VariableName',Countries);

P9010.t_init=array2table(squeeze(Big_t_init(3,1,:,:))','VariableName',Countries);
P9050.t_init=array2table(squeeze(Big_t_init(3,2,:,:))','VariableName',Countries);
P5010.t_init=array2table(squeeze(Big_t_init(3,3,:,:))','VariableName',Countries);

P9010.t_end=array2table(squeeze(Big_t_end(3,1,:,:))','VariableName',Countries);
P9050.t_end=array2table(squeeze(Big_t_end(3,2,:,:))','VariableName',Countries);
P5010.t_end=array2table(squeeze(Big_t_end(3,3,:,:))','VariableName',Countries);

P9010.mean_gdp=array2table(squeeze(Big_mean_gdp(3,1,:,:))','VariableName',Countries);
P9050.mean_gdp=array2table(squeeze(Big_mean_gdp(3,2,:,:))','VariableName',Countries);
P5010.mean_gdp=array2table(squeeze(Big_mean_gdp(3,3,:,:))','VariableName',Countries);

P9010.std_gdp=array2table(squeeze(Big_std_gdp(3,1,:,:))','VariableName',Countries);
P9050.std_gdp=array2table(squeeze(Big_std_gdp(3,2,:,:))','VariableName',Countries);
P5010.std_gdp=array2table(squeeze(Big_std_gdp(3,3,:,:))','VariableName',Countries);

P9010.R2_adj=array2table(squeeze(Big_R2_adjusted(3,1,:,:))','VariableName',Countries);
P9050.R2_adj=array2table(squeeze(Big_R2_adjusted(3,2,:,:))','VariableName',Countries);
P5010.R2_adj=array2table(squeeze(Big_R2_adjusted(3,3,:,:))','VariableName',Countries);

P9010.R2_ord=array2table(squeeze(Big_R2_ordinary(3,1,:,:))','VariableName',Countries);
P9050.R2_ord=array2table(squeeze(Big_R2_ordinary(3,2,:,:))','VariableName',Countries);
P5010.R2_ord=array2table(squeeze(Big_R2_ordinary(3,3,:,:))','VariableName',Countries);

end